capture log close
set matsize 10000

*Data downloaded from the website of Loukas Karabarbounis (https://sites.google.com/site/loukaskarabarbounis/research) on May 13, 2016
use "ui_crk.dta", clear

log using endog_figs_final.log, replace

sort month state
by month: gen state_id=_n

sort state month
by state: gen counter=_n
gen year=1996+floor((counter-1)/12)
gen month=1+mod(counter-1,12)

xtset state_id monthly

gen T_rev = T-T_hat

gen u_err = u_realtime - u_revised

la var T_rev "Hypothetical Benefits"
la var u_err "Unemployment Error"


sort state_id monthly

*Numbers on page 4
qui	reghdfe u_revised T_hat  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)
est table, keep(T_hat) b se t
qui	reghdfe u_revised epsilon  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)
est table, keep(epsilon) b se t


 matrix xx = J(3,17,.)

 forvalues x=-8(1)8{
   matrix xx[1,`x'+9]=`x'
   matrix xx[2,`x'+9]=`x'
   matrix xx[3,`x'+9]=`x'
   }

 matrix xxh = J(6,17,.)

 forvalues x=-8(1)8{
   matrix xxh[1,`x'+9]=`x'
   matrix xxh[2,`x'+9]=`x'
   matrix xxh[3,`x'+9]=`x'
   matrix xxh[4,`x'+9]=`x'
   matrix xxh[5,`x'+9]=`x'
   matrix xxh[6,`x'+9]=`x'
   }

   

matrix placebo_results3=J(17,3,.)

* Figure 2
global regvar="epsilon"
forvalues x=0(1)8{



qui	reghdfe phi L(`x').$regvar  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(L(`x').$regvar) b se t
matrix placebo_results3[9-`x',1]=_b[L`x'.$regvar]
matrix placebo_results3[9-`x',2]=_se[L`x'.$regvar]*-1.68+_b[L`x'.$regvar]
matrix placebo_results3[9-`x',3]=_se[L`x'.$regvar]*1.68+_b[L`x'.$regvar]
}
forvalues x=1(1)8{


qui	reghdfe phi F(`x').$regvar  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)



est table, keep(F(`x').$regvar) b se t
matrix placebo_results3[`x'+9,1]=_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,2]=_se[F`x'.$regvar]*-1.68+_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,3]=_se[F`x'.$regvar]*1.68+_b[F`x'.$regvar]

}


coefplot (matrix(placebo_results3[,1]), ci((placebo_results3[,2] placebo_results3[,3]))), ytitle(Coefficient on $regvar) at(xx) yline(0) xlab(-8(1)8)
graph save claims_IRF_${regvar}, replace
graph export claims_IRF_${regvar}.pdf, replace

* Figure 1
global regvar="epsilon"
forvalues x=0(1)8{



qui	reghdfe u_revised L(`x').$regvar  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(L(`x').$regvar) b se t
matrix placebo_results3[9-`x',1]=_b[L`x'.$regvar]
matrix placebo_results3[9-`x',2]=_se[L`x'.$regvar]*-1.68+_b[L`x'.$regvar]
matrix placebo_results3[9-`x',3]=_se[L`x'.$regvar]*1.68+_b[L`x'.$regvar]
}
forvalues x=1(1)8{


qui	reghdfe u_revised F(`x').$regvar  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)



est table, keep(F(`x').$regvar) b se t
matrix placebo_results3[`x'+9,1]=_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,2]=_se[F`x'.$regvar]*-1.68+_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,3]=_se[F`x'.$regvar]*1.68+_b[F`x'.$regvar]

}


coefplot (matrix(placebo_results3[,1]), ci((placebo_results3[,2] placebo_results3[,3]))), ytitle(Coefficient on $regvar) at(xx) yline(0) xlab(-8(1)8)
graph save urev_IRF_${regvar}, replace
graph export urev_IRF_${regvar}.pdf, replace


* Figure 3
global regvar="epsilon"
matrix placebo_resultsH=J(17,6,.)

forvalues x=0(1)8{

qui	reghdfe $regvar L(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)
matrix placebo_resultsH[9-`x',1]=_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',2]=_se[L`x'.u_err]*-1.68+_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',3]=_se[L`x'.u_err]*1.68+_b[L`x'.u_err]

est table, keep(L(`x').u_err) b se t
qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9-`x',4]=_b[v]/100
matrix placebo_resultsH[9-`x',5]=(_se[v]*-1.68+_b[v])/100
matrix placebo_resultsH[9-`x',6]=(_se[v]*1.68+_b[v])/100

drop v 

}



forvalues x=1(1)8{

qui	reghdfe $regvar F(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').u_err) b se t
matrix placebo_resultsH[9+`x',1]=_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',2]=_se[F`x'.u_err]*-1.68+_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',3]=_se[F`x'.u_err]*1.68+_b[F`x'.u_err]

qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9+`x',4]=_b[v]/100
matrix placebo_resultsH[9+`x',5]=(_se[v]*-1.68+_b[v])/100
matrix placebo_resultsH[9+`x',6]=(_se[v]*1.68+_b[v])/100


drop v 

}

coefplot (matrix(placebo_resultsH[,1]), ci((placebo_resultsH[,2] placebo_resultsH[,3])) lab("First Stage"))  (matrix(placebo_resultsH[,4]), ci((placebo_resultsH[,5] placebo_resultsH[,6])) lab("Residual/100")), at(xxh) yline(0)  xlab(-8(1)8)
graph save urev_IRF_Hausman_${regvar}, replace
graph export urev_IRF_Hausman_${regvar}.pdf, replace

global regvar="T_hat"
matrix placebo_resultsH=J(17,6,.)

forvalues x=0(1)8{

qui	reghdfe $regvar L(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)
matrix placebo_resultsH[9-`x',1]=_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',2]=_se[L`x'.u_err]*-1.68+_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',3]=_se[L`x'.u_err]*1.68+_b[L`x'.u_err]

est table, keep(L(`x').u_err) b se t
qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9-`x',4]=_b[v]/10
matrix placebo_resultsH[9-`x',5]=(_se[v]*-1.68+_b[v])/10
matrix placebo_resultsH[9-`x',6]=(_se[v]*1.68+_b[v])/10

drop v 

}



forvalues x=1(1)8{

qui	reghdfe $regvar F(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').u_err) b se t
matrix placebo_resultsH[9+`x',1]=_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',2]=_se[F`x'.u_err]*-1.68+_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',3]=_se[F`x'.u_err]*1.68+_b[F`x'.u_err]

qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9+`x',4]=_b[v]/10
matrix placebo_resultsH[9+`x',5]=(_se[v]*-1.68+_b[v])/10
matrix placebo_resultsH[9+`x',6]=(_se[v]*1.68+_b[v])/10


drop v 

}

coefplot (matrix(placebo_resultsH[,1]), ci((placebo_resultsH[,2] placebo_resultsH[,3])) lab("First Stage"))  (matrix(placebo_resultsH[,4]), ci((placebo_resultsH[,5] placebo_resultsH[,6])) lab("Residual/10")), at(xxh) yline(0)  xlab(-8(1)8)
graph save urev_IRF_Hausman_${regvar}, replace
graph export urev_IRF_Hausman_${regvar}.pdf, replace




global regvar="T"
matrix placebo_resultsH=J(17,6,.)

forvalues x=0(1)8{

qui	reghdfe $regvar L(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)
matrix placebo_resultsH[9-`x',1]=_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',2]=_se[L`x'.u_err]*-1.68+_b[L`x'.u_err]
matrix placebo_resultsH[9-`x',3]=_se[L`x'.u_err]*1.68+_b[L`x'.u_err]

est table, keep(L(`x').u_err) b se t
qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9-`x',4]=_b[v]/10
matrix placebo_resultsH[9-`x',5]=(_se[v]*-1.68+_b[v])/10
matrix placebo_resultsH[9-`x',6]=(_se[v]*1.68+_b[v])/10

drop v 

}



forvalues x=1(1)8{

qui	reghdfe $regvar F(`x').u_err  if baseline_sample,  residuals(v) absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').u_err) b se t
matrix placebo_resultsH[9+`x',1]=_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',2]=_se[F`x'.u_err]*-1.68+_b[F`x'.u_err]
matrix placebo_resultsH[9+`x',3]=_se[F`x'.u_err]*1.68+_b[F`x'.u_err]

qui	reghdfe u_revised $regvar v  if baseline_sample,  absorb(state_id monthly) cluster(state_id monthly)

est table, keep(v) b se t
matrix placebo_resultsH[9+`x',4]=_b[v]/10
matrix placebo_resultsH[9+`x',5]=(_se[v]*-1.68+_b[v])/10
matrix placebo_resultsH[9+`x',6]=(_se[v]*1.68+_b[v])/10


drop v 

}

coefplot (matrix(placebo_resultsH[,1]), ci((placebo_resultsH[,2] placebo_resultsH[,3])) lab("First Stage"))  (matrix(placebo_resultsH[,4]), ci((placebo_resultsH[,5] placebo_resultsH[,6])) lab("Residual/10")), at(xxh) yline(0)  xlab(-8(1)8)
graph save urev_IRF_Hausman_${regvar}, replace
graph export urev_IRF_Hausman_${regvar}.pdf, replace



*Figure 4
global regvar="T_hat"
forvalues x=0(1)8{


qui	reghdfe T_rev L(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(L(`x').$regvar) b se t

matrix placebo_results3[9-`x',1]=_b[L`x'.$regvar]
matrix placebo_results3[9-`x',2]=_se[L`x'.$regvar]*-1.68+_b[L`x'.$regvar]
matrix placebo_results3[9-`x',3]=_se[L`x'.$regvar]*1.68+_b[L`x'.$regvar]

}

forvalues x=1(1)8{

qui	reghdfe T_rev F(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').$regvar) b se t
matrix placebo_results3[`x'+9,1]=_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,2]=_se[F`x'.$regvar]*-1.68+_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,3]=_se[F`x'.$regvar]*1.68+_b[F`x'.$regvar]

}

coefplot (matrix(placebo_results3[,1]), ci((placebo_results3[,2] placebo_results3[,3]))), ytitle(Coefficient on $regvar) at(xx) yline(0)  xlab(-8(1)8)
graph save Trev_IRF_${regvar}, replace
graph export Trev_IRF_${regvar}.pdf, replace

global regvar="u_err"

forvalues x=0(1)8{


qui	reghdfe epsilon L(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(L(`x').$regvar) b se t
matrix placebo_results3[9-`x',1]=_b[L`x'.$regvar]
matrix placebo_results3[9-`x',2]=_se[L`x'.$regvar]*-1.68+_b[L`x'.$regvar]
matrix placebo_results3[9-`x',3]=_se[L`x'.$regvar]*1.68+_b[L`x'.$regvar]

}

forvalues x=1(1)8{


qui	reghdfe epsilon F(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').$regvar) b se t
matrix placebo_results3[`x'+9,1]=_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,2]=_se[F`x'.$regvar]*-1.68+_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,3]=_se[F`x'.$regvar]*1.68+_b[F`x'.$regvar]

}

coefplot (matrix(placebo_results3[,1]), ci((placebo_results3[,2] placebo_results3[,3]))), ytitle(Coefficient on $regvar) at(xx) yline(0)  xlab(-8(1)8)
graph save epsilon_IRF_${regvar}, replace
graph export epsilon_IRF_${regvar}.pdf, replace

global regvar="u_err"

forvalues x=0(1)8{


qui	reghdfe u_revised L(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(L(`x').$regvar) b se t
matrix placebo_results3[9-`x',1]=_b[L`x'.$regvar]
matrix placebo_results3[9-`x',2]=_se[L`x'.$regvar]*-1.68+_b[L`x'.$regvar]
matrix placebo_results3[9-`x',3]=_se[L`x'.$regvar]*1.68+_b[L`x'.$regvar]

}

forvalues x=1(1)8{


qui	reghdfe u_revised F(`x').$regvar  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep(F(`x').$regvar) b se t
matrix placebo_results3[`x'+9,1]=_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,2]=_se[F`x'.$regvar]*-1.68+_b[F`x'.$regvar]
matrix placebo_results3[`x'+9,3]=_se[F`x'.$regvar]*1.68+_b[F`x'.$regvar]

}

coefplot (matrix(placebo_results3[,1]), ci((placebo_results3[,2] placebo_results3[,3]))), ytitle(Coefficient on $regvar) at(xx) yline(0)  xlab(-8(1)8)
graph save urev_IRF_${regvar}, replace
graph export urev_IRF_${regvar}.pdf, replace











*Figure 5
global regvar="epsilon"

forvalues x=0(1)8{


qui	reghdfe u_revised ($regvar=L(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9-`x',1]=_b[$regvar]
matrix placebo_results3[9-`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9-`x',3]=_se[$regvar]*1.68+_b[$regvar]

}

forvalues x=1(1)8{


qui	reghdfe u_revised ($regvar=F(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9+`x',1]=_b[$regvar]
matrix placebo_results3[9+`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9+`x',3]=_se[$regvar]*1.68+_b[$regvar]

}
matrix tempr = J(11,3,.)
matrix tempr = placebo_results3[4..14,1..3]
matrix tempx = J(3,11,.)
matrix tempx = xx[1..3,4..14]
coefplot (matrix(tempr[,1]), ci((tempr[,2] tempr[,3]))), ytitle(Coefficient on $regvar) at(tempx) yline(0)  xlab(-5(1)5) xsc(r(-5 5))
graph save urev_IRF_${regvar}_IV_u_err, replace
graph export urev_IRF_${regvar}_IV_u_err.pdf, replace



global regvar="T"

forvalues x=0(1)8{


qui	reghdfe u_revised ($regvar=L(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9-`x',1]=_b[$regvar]
matrix placebo_results3[9-`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9-`x',3]=_se[$regvar]*1.68+_b[$regvar]

}

forvalues x=1(1)8{


qui	reghdfe u_revised ($regvar=F(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9+`x',1]=_b[$regvar]
matrix placebo_results3[9+`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9+`x',3]=_se[$regvar]*1.68+_b[$regvar]

}

matrix tempr = J(11,3,.)
matrix tempr = placebo_results3[4..14,1..3]
matrix tempx = J(3,11,.)
matrix tempx = xx[1..3,4..14]
coefplot (matrix(tempr[,1]), ci((tempr[,2] tempr[,3]))), ytitle(Coefficient on $regvar) at(tempx) yline(0)  xlab(-5(1)5) xsc(r(-5 5))

graph save urev_IRF_${regvar}_IV_u_err, replace
graph export urev_IRF_${regvar}_IV_u_err.pdf, replace

global regvar="T_hat"

forvalues x=0(1)8{


qui	reghdfe u_revised ($regvar=L(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9-`x',1]=_b[$regvar]
matrix placebo_results3[9-`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9-`x',3]=_se[$regvar]*1.68+_b[$regvar]

}

forvalues x=1(1)8{


qui	reghdfe u_revised ($regvar=F(`x').u_err)  if baseline_sample, absorb(state_id monthly) cluster(state_id monthly)

est table, keep($regvar) b se t
matrix placebo_results3[9+`x',1]=_b[$regvar]
matrix placebo_results3[9+`x',2]=_se[$regvar]*-1.68+_b[$regvar]
matrix placebo_results3[9+`x',3]=_se[$regvar]*1.68+_b[$regvar]

}

matrix tempr = J(11,3,.)
matrix tempr = placebo_results3[4..14,1..3]
matrix tempx = J(3,11,.)
matrix tempx = xx[1..3,4..14]
coefplot (matrix(tempr[,1]), ci((tempr[,2] tempr[,3]))), ytitle(Coefficient on $regvar) at(tempx) yline(0)  xlab(-5(1)5) xsc(r(-5 5))

graph save urev_IRF_${regvar}_IV_u_err, replace
graph export urev_IRF_${regvar}_IV_u_err.pdf, replace


log close


